@@ -1,7 +1,7 @@
 
 from .finder.core import FinderFactory
 from .parser import DoxygenParserFactory
-from .renderer import DoxygenToRstRendererFactoryCreator
+from .renderer import DoxygenToRstRendererFactory
 from .renderer.base import RenderContext
 from .renderer.filter import FilterFactory
 from .renderer.target import TargetHandlerFactory
@@ -172,8 +172,6 @@ class DoxygenFunctionDirective(BaseDirective):
     def parse_args(self, function_description):
         # Strip off trailing qualifiers
         pattern = re.compile(r'''(?<= \)) \s*
-                             (?: const)? \s*
-                             (?: volatile)? \s*
                              (?: = \s* 0)? \s* $ ''',
                              re.VERBOSE)
 
@@ -392,14 +390,14 @@ class DoxygenContentBlockDirective(BaseDirective):
             )
         filter_ = self.filter_factory.create_render_filter(self.kind, self.options)
 
-        renderer_factory_creator = DoxygenToRstRendererFactoryCreator(
+        renderer_factory = DoxygenToRstRendererFactory(
             self.parser_factory,
             project_info
             )
         node_list = []
 
         for node_stack in matches:
-            renderer_factory = renderer_factory_creator.create_factory(
+            object_renderer = renderer_factory.create_renderer(
                 node_stack,
                 self.state,
                 self.state.document,
@@ -409,8 +407,7 @@ class DoxygenContentBlockDirective(BaseDirective):
 
             mask_factory = NullMaskFactory()
             context = RenderContext(node_stack, mask_factory, self.directive_args)
-            object_renderer = renderer_factory.create_renderer(context)
-            node_list.extend(object_renderer.render())
+            node_list.extend(object_renderer.render(context.node_stack[0], context))
 
         return node_list
 
@@ -728,7 +725,7 @@ class FileStateCache(object):
 
         stale = []
 
-        for filename, info in self.app.env.breathe_file_state.iteritems():
+        for filename, info in self.app.env.breathe_file_state.items():
             old_mtime, docnames = info
             if self.mtimer.get_mtime(filename) > old_mtime:
                 stale.extend(docnames)
@@ -742,7 +739,7 @@ class FileStateCache(object):
 
         toremove = []
 
-        for filename, info in self.app.env.breathe_file_state.iteritems():
+        for filename, info in self.app.env.breathe_file_state.items():
 
             _, docnames = info
             docnames.discard(docname)
@@ -838,12 +835,12 @@ def setup(app):
             app.config.breathe_doxygen_config_options
         )
 
-    app.connect("builder-inited", doxygen_hook)
-
     app.connect("builder-inited", directive_factory.get_config_values)
 
     app.connect("builder-inited", filter_factory.get_config_values)
 
+    app.connect("builder-inited", doxygen_hook)
+
     app.connect("env-get-outdated", file_state_cache.get_outdated)
 
     app.connect("env-purge-doc", file_state_cache.purge_doc)
