@@ -673,7 +673,7 @@ class FilterFactory(object):
             'private-members': 'private',
             }
 
-        for option, scope in all_options.iteritems():
+        for option, scope in all_options.items():
             if option in options:
                 allowed.add(scope)
 
@@ -1059,7 +1059,9 @@ class FilterFactory(object):
 
         if namespace:
             parent_matches = (parent.node_type == 'compound') \
-                & ((parent.kind == 'namespace') | (parent.kind == 'class')) \
+                & ((parent.kind == 'namespace') |
+                   (parent.kind == 'class') |
+                   (parent.kind == 'struct')) \
                 & (parent.name == namespace)
 
             return parent_matches & node_matches
